@@ -6,7 +6,7 @@ from time import time
 from types import FunctionType, MethodType
 from pyevents.manager import EventDispatcher
 from pyevents.event import Event
-from specter.util import get_real_last_traceback
+from specter.util import get_real_last_traceback, convert_camelcase
 
 
 class TimedObject(object):
@@ -60,7 +60,7 @@ class CaseWrapper(TimedObject):
 
     @property
     def name(self):
-        return self.case_func.__name__
+        return convert_camelcase(self.case_func.__name__)
 
     @property
     def pretty_name(self):
@@ -87,21 +87,18 @@ class Describe(EventDispatcher):
         self.describes = [desc_type(parent=self)
                           for desc_type in self.describe_types]
 
-        shuffle(self.cases)
-        shuffle(self.describes)
-
     @property
     def name(self):
-        return self.__class__.__name__
+        return convert_camelcase(self.__class__.__name__)
 
     @property
     def doc(self):
         return type(self).__doc__
 
-    @property
-    def __members__(self):
+    @classmethod
+    def __cls_members__(cls):
         all_members = {}
-        classes = list(type(self).__bases__) + [type(self)]
+        classes = list(cls.__bases__) + [cls]
 
         for klass in classes:
             pairs = dict((key, val) for key, val in vars(klass).items())
@@ -109,6 +106,21 @@ class Describe(EventDispatcher):
 
         return all_members
 
+    @classmethod
+    def __get_all_child_describes__(cls):
+        members = cls.__cls_members__()
+        child_describes = [val for key, val in members.items()
+                           if Describe.plugin_filter(val)]
+        all_children = child_describes + [cls]
+
+        for child in child_describes:
+            all_children.extend(child.__get_all_child_describes__())
+        return set(all_children)
+
+    @property
+    def __members__(self):
+        return type(self).__cls_members__()
+
     @property
     def describe_types(self):
         return [val for key, val in self.__members__.items()
